@@ -3,12 +3,12 @@ package Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 use strict;
 use JSON qw(to_json from_json);
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 sub serialize {
     my $session = shift;
 
-    $session->{serialized} = to_json( $session->{data} );
+    $session->{serialized} = to_json( $session->{data}, { allow_nonref => 1 } );
 }
 
 sub unserialize {
@@ -36,7 +36,7 @@ sub decodeThaw64 {
 sub _unserialize {
     my ( $serialized, $next ) = @_;
     my $tmp;
-    eval { $tmp = from_json($serialized) };
+    eval { $tmp = from_json( $serialized, { allow_nonref => 1 } ) };
     if ($@) {
         require Storable;
         $next ||= \&Storable::thaw;
@@ -90,12 +90,12 @@ L<JSON>, L<Apache::Session>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
