@@ -119,7 +119,6 @@ sub saveConf {
     my ( $self, $conf, %args ) = @_;
 
     my $last = $self->lastCfg;
-    return UNKNOWN_ERROR if $last < 1;
 
     # If configuration was modified, return an error
     if ( not $args{force} ) {
@@ -601,7 +600,7 @@ L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
