@@ -5,7 +5,7 @@ use utf8;
 use DBI;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.12';
 our @ISA     = qw(Lemonldap::NG::Common::Conf::Constants);
 our ( @EXPORT, %EXPORT_TAGS );
 
@@ -36,8 +36,8 @@ sub available {
     my $sth =
       $self->_dbh->prepare( "SELECT DISTINCT cfgNum from "
           . $self->{dbiTable}
-          . " order by cfgNum" );
-    $sth->execute();
+          . " order by cfgNum" ) or $self->logError;
+    $sth->execute() or $self->logError;
     my @conf;
     while ( my @row = $sth->fetchrow_array ) {
         push @conf, $row[0];
@@ -56,13 +56,28 @@ sub _dbh {
     my $self = shift;
     $self->{dbiTable} ||= "lmConfig";
     return $self->{_dbh} if ( $self->{_dbh} and $self->{_dbh}->ping );
-    return DBI->connect_cached( $self->{dbiChain}, $self->{dbiUser},
+    $self->{_dbh} = DBI->connect_cached( $self->{dbiChain}, $self->{dbiUser},
         $self->{dbiPassword}, { RaiseError => 1, AutoCommit => 1, } );
+    if ( $self->{dbiChain} =~ /^dbi:sqlite/i ) {
+        $self->{_dbh}->{sqlite_unicode} = 1;
+    }
+    elsif ( $self->{dbiChain} =~ /^dbi:mysql/i ) {
+        eval {
+            $self->{_dbh}->{mysql_enable_utf8} = 1;
+            $self->{_dbh}->do("set names 'utf8'");
+        };
+    }
+    elsif ( $self->{dbiChain} =~ /^dbi:pg/i ) {
+        $self->{_dbh}->{pg_enable_utf8} = 1;
+    }
+
+    # DBD::MariaDB should have o problem here
+    return $self->{_dbh};
 }
 
 sub lock {
     my $self = shift;
-    if ( $self->{dbiChain} =~ /^dbi:mysql:/i ) {
+    if ( $self->{dbiChain} =~ /^dbi:(?:MariaDB|mysql):/i ) {
         my @row = $self->_dbh->selectrow_array("SELECT GET_LOCK('lmconf', 0)");
         return $row[0] || 0;
     }
@@ -71,7 +86,7 @@ sub lock {
 
 sub isLocked {
     my $self = shift;
-    if ( $self->{dbiChain} =~ /^dbi:mysql:/i ) {
+    if ( $self->{dbiChain} =~ /^dbi:(?:MariaDB|mysql):/i ) {
         my @row = $self->_dbh->selectrow_array("SELECT IS_FREE_LOCK('lmconf')");
         return $row[0] ? 0 : 1;
     }
@@ -80,7 +95,7 @@ sub isLocked {
 
 sub unlock {
     my $self = shift;
-    if ( $self->{dbiChain} =~ /^dbi:mysql:/i ) {
+    if ( $self->{dbiChain} =~ /^dbi:(?:MariaDB|mysql):/i ) {
         my @row = $self->_dbh->selectrow_array("SELECT RELEASE_LOCK('lmconf')");
         return $row[0] || 0;
     }
@@ -90,8 +105,9 @@ sub unlock {
 sub delete {
     my ( $self, $cfgNum ) = @_;
     my $req =
-      $self->_dbh->prepare("DELETE FROM $self->{dbiTable} WHERE cfgNum=?");
-    my $res = $req->execute($cfgNum);
+      $self->_dbh->prepare("DELETE FROM $self->{dbiTable} WHERE cfgNum=?")
+        or $self->logError;
+    my $res = $req->execute($cfgNum) or $self->logError;
     $Lemonldap::NG::Common::Conf::msg .=
       "Unable to find conf $cfgNum (" . $self->_dbh->errstr . ")"
       unless ($res);
@@ -101,8 +117,7 @@ sub delete {
 sub logError {
     my $self = shift;
     $Lemonldap::NG::Common::Conf::msg .=
-      "Database error: " . $self->_dbh->errstr . "\n";
+      "Database error: " . $DBI::errstr . "\n";
 }
 
 1;
-__END__
