@@ -2,9 +2,8 @@ package Lemonldap::NG::Common::Logger::Log4perl;
 
 use strict;
 use Log::Log4perl;
-use Mouse;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 our $init = 0;
 
