@@ -2,15 +2,16 @@ package Lemonldap::NG::Common::Logger::Std;
 
 use strict;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.5';
 
 sub new {
     no warnings 'redefine';
     my $level = $_[1]->{logLevel} || 'info';
-    my $show = 1;
+    my $show  = 1;
     foreach (qw(error warn notice info debug)) {
         if ($show) {
-            eval qq'sub $_ {print STDERR "[$_] \$_[1]\n"}';
+            eval
+qq'sub $_ {print STDERR "[".localtime."] [LLNG:\$\$] [$_] \$_[1]\n"}';
         }
         else {
             eval qq'sub $_ {1}';
