@@ -258,7 +258,7 @@ sub sendJs {
     return [
         200,
         [
-            'Content-Type'   => 'application/json',
+            'Content-Type'   => 'application/javascript',
             'Content-Length' => length($s),
             'Cache-Control'  => 'public,max-age=2592000',
         ],
@@ -536,7 +536,7 @@ L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
